View source: R/UserFunctions.R
| getCustomOutput | R Documentation |
Getting the custom output
getCustomOutput(metapop)
metapop |
a |
The list generated through the custom result function, if at least
it was specified during the simulation of the Metapopulation.
Ehouarn Le Faou
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.