View source: R/UserFunctions.R
| setSelectOnGametes | R Documentation |
Generation of an object of the Selection class which defines a
selection among the individuals either by adding this type of selection
to an already existing SelectionObj object (parameter
selectionObj) or by creating one.
setSelectOnGametes( genomeObj = NULL, gamFit = c(), femaleFit = c(), maleFit = c(), selectionObj = NULL )
genomeObj |
a |
gamFit |
an haplotypic fitness vector for all individuals |
femaleFit |
an haplotypic fitness vector for females only |
maleFit |
an haplotypic fitness vector for males only |
selectionObj |
a |
a Selection object
Ehouarn Le Faou
DL <- list(dl = c("A", "a"))
HL <- list(hl = c("B", "b"))
genomeObj <- setGenome(listHapLoci = HL, listDipLoci = DL)
selectionObj <- setSelectOnGametes(
genomeObj = genomeObj,
gamFit = c(1, 1, 0.5, 0)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.