View source: R/UserFunctions.R
| setSelectOnGametesProd | R Documentation |
Generation of an object of the Selection class which defines a
selection on the gamete production either by adding this type of selection
to an already existing SelectionObj object (parameter
selectionObj) or by creating one.
setSelectOnGametesProd( genomeObj = NULL, indProdFit = c(), femProdFit = c(), maleProdFit = c(), selectionObj = NULL )
genomeObj |
a |
indProdFit |
a genotypic fitness vector for all individuals |
femProdFit |
a genotypic fitness vector for females only |
maleProdFit |
a genotypic fitness vector for males only |
selectionObj |
a |
a Selection object
Ehouarn Le Faou
DL <- list(dl = c("A", "a"))
HL <- list(hl = c("B", "b"))
genomeObj <- setGenome(listHapLoci = HL, listDipLoci = DL)
selectionObj <- setSelectOnGametesProd(
genomeObj = genomeObj,
indProdFit = c(1, 1, 1, 1, 0.5, 0)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.