View source: R/UserFunctions.R
| setSelectOnInds | R Documentation |
Generation of an object of the Selection class which defines a
selection among the individuals either by adding this type of selection
to an already existing SelectionObj object (parameter
selectionObj) or by creating one.
setSelectOnInds( genomeObj = NULL, indFit = c(), femaleFit = c(), maleFit = c(), selectionObj = NULL )
genomeObj |
a |
indFit |
a genotypic fitness vector for all individuals (whether or not they are hermaphordite) |
femaleFit |
a genotypic fitness vector for females only (only if the population is dioecious) |
maleFit |
a genotypic fitness vector for males only (only if the population is dioecious) |
selectionObj |
a |
a Selection object
Ehouarn Le Faou
DL <- list(dl = c("A", "a"))
HL <- list(hl = c("B", "b"))
genomeObj <- setGenome(listHapLoci = HL, listDipLoci = DL)
selectionObj <- setSelectOnInds(
genomeObj = genomeObj,
indFit = c(1, 1, 1, 1, 0.5, 0)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.